@@ -19,7 +19,7 @@ CONF_KEY_TYPE = 'type'
 CONF_KEY_DEST = 'dest'
 
 CONF_KEY_LOG_FILE_PATH = "log_file"
-DEFAULT_LOG_FILE_PATH = "logs/pyqt.log"
+DEFAULT_LOG_FILE_PATH = "logs/runtime.log"
 
 EXIT_CODE_NORMAL = 0
 EXIT_CODE_CONF_ERROR = 1
