@@ -131,7 +131,7 @@ def init_context(executing_path, conf_file):
 def add_extendable_instances(context, conf_keys, add_fn):
     conf = context.get_conf().get(*conf_keys)
     if not conf:
-        logging.info("skip adding extendable instances of type {} without conf".format(type))
+        logging.info("skip adding extendable instances of type {} without conf".format(conf_keys))
         return
     if isinstance(conf, list):
         conf_dict = dict()
